@@ -5,7 +5,7 @@ import hashlib
 from functools import partial
 from s3fs import S3FileSystem
 
-CHUNK_SIZE = 2 ** 20
+CHUNK_SIZE = 2**20
 
 
 def get_hash_local(files_to_hash: Collection) -> str:
@@ -20,8 +20,8 @@ def get_hash_local(files_to_hash: Collection) -> str:
     """
     hash_md5 = hashlib.md5()
     for filename in sorted(files_to_hash):
-        with open(filename, 'rb') as infile:
-            for chunk in iter(partial(infile.read, CHUNK_SIZE), b''):
+        with open(filename, "rb") as infile:
+            for chunk in iter(partial(infile.read, CHUNK_SIZE), b""):
                 hash_md5.update(chunk)
     return hash_md5.hexdigest()
 
@@ -39,7 +39,7 @@ def get_hash_s3(files_to_hash: Collection) -> str:
     hash_md5 = hashlib.md5()
     fs = S3FileSystem()
     for filename in sorted(files_to_hash):
-        with fs.open(filename, 'rb') as infile:
-            for chunk in iter(partial(infile.read, CHUNK_SIZE), b''):
+        with fs.open(filename, "rb") as infile:
+            for chunk in iter(partial(infile.read, CHUNK_SIZE), b""):
                 hash_md5.update(chunk)
     return hash_md5.hexdigest()
